@@ -15,6 +15,7 @@ ${AUTOGENERATION_WARNING}
 
 from labscript_devices.NI_DAQmx.labscript_devices import NI_DAQmx
 
+#:
 CAPABILITIES = ${CAPABILITIES}
 
 
@@ -22,6 +23,7 @@ class ${CLASS_NAME}(NI_DAQmx):
     description = '${MODEL_NAME}'
 
     def __init__(self, *args, **kwargs):
+        """Class for ${MODEL_NAME}"""
         # Any provided kwargs take precedent over capabilities
         combined_kwargs = CAPABILITIES.copy()
         combined_kwargs.update(kwargs)
